@@ -865,7 +865,7 @@ def computeRefinement2(curve,curveSegNormalized,param,paramSegNormalized,knots,r
     errors[nintknots] = dhd.item()
     errorsMSE[nintknots] = mse.item()
     
-    knots_tmp = torch.zeros(nMaxKnots)
+    knots_tmp = torch.zeros(2*(k+1)+nMaxKnots)
     knots_tmp[:knots.shape[0]] = knots
         
     return spline,knots_tmp,c,errors,errorsMSE
